@@ -4,6 +4,7 @@
  * libmbim-glib -- GLib/GIO based library to control MBIM devices
  *
  * Copyright (C) 2013 - 2014 Aleksander Morgado <aleksander@aleksander.es>
+ * Copyright (C) 2022 Intel Corporation
  */
 
 #include "mbim-cid.h"
@@ -171,11 +172,14 @@ static const CidConfig cid_ms_basic_connect_extensions_config [MBIM_CID_MS_BASIC
 };
 
 /* Note: index of the array is CID-1 */
-#define MBIM_CID_QDU_LAST MBIM_CID_QDU_FILE_WRITE
+#define MBIM_CID_QDU_LAST MBIM_CID_QDU_COMMAND
 static const CidConfig cid_qdu_config [MBIM_CID_QDU_LAST] = {
     { SET,    QUERY,    NOTIFY    }, /* MBIM_CID_QDU_UPDATE_SESSION */
     { SET,    NO_QUERY, NO_NOTIFY }, /* MBIM_CID_QDU_FILE_OPEN */
     { SET,    NO_QUERY, NO_NOTIFY }, /* MBIM_CID_QDU_FILE_WRITE */
+    { SET,    NO_QUERY, NO_NOTIFY }, /* MBIM_CID_QDU_QUECTEL_REBOOT */
+    { SET,    NO_QUERY, NO_NOTIFY }, /* MBIM_CID_QDU_QUECTEL_READ_VERSION */
+    { SET,    NO_QUERY, NO_NOTIFY }, /* MBIM_CID_QDU_COMMAND */
 };
 
 /* Note: index of the array is CID-1 */
@@ -228,6 +232,48 @@ static const CidConfig cid_ms_voice_extensions_config [MBIM_CID_MS_VOICE_EXTENSI
     { NO_SET,    QUERY,    NOTIFY }, /* MBIM_CID_MS_VOICE_EXTENSIONS_NITZ */
 };
 
+/* Note: index of the array is CID-1 */
+#define MBIM_CID_INTEL_MUTUAL_AUTHENTICATION_LAST MBIM_CID_INTEL_MUTUAL_AUTHENTICATION_FCC_LOCK
+static const CidConfig cid_intel_mutual_authentication_config [MBIM_CID_INTEL_MUTUAL_AUTHENTICATION_LAST] = {
+    { SET, QUERY, NO_NOTIFY }, /* MBIM_CID_INTEL_MUTUAL_AUTHENTICATION_FCC_LOCK */
+};
+
+/* Note: index of the array is CID-1 */
+#define MBIM_CID_INTEL_TOOLS_LAST MBIM_CID_INTEL_TOOLS_TRACE_CONFIG
+static const CidConfig cid_intel_tools_config [MBIM_CID_INTEL_TOOLS_LAST] = {
+    { NO_SET, NO_QUERY, NO_NOTIFY }, /* Unused */
+    { NO_SET, NO_QUERY, NO_NOTIFY }, /* Unused */
+    { NO_SET, NO_QUERY, NO_NOTIFY }, /* Unused */
+    { NO_SET, NO_QUERY, NO_NOTIFY }, /* Unused */
+    { NO_SET, NO_QUERY, NO_NOTIFY }, /* Unused */
+    { NO_SET, NO_QUERY, NO_NOTIFY }, /* Unused */
+    { NO_SET, NO_QUERY, NO_NOTIFY }, /* Unused */
+    { SET   , QUERY   , NO_NOTIFY }, /* MBIM_CID_INTEL_TOOLS_TRACE_CONFIG */
+};
+
+/* Note: index of the array is CID-1 */
+#define MBIM_CID_GOOGLE_LAST MBIM_CID_GOOGLE_CARRIER_LOCK
+static const CidConfig cid_google_config [MBIM_CID_GOOGLE_LAST] = {
+    { SET, QUERY, NOTIFY }, /* MBIM_CID_GOOGLE_CARRIER_LOCK */
+};
+
+/* Note: index of the array is CID-1 */
+#define MBIM_CID_FIBOCOM_LAST MBIM_CID_FIBOCOM_AT_COMMAND
+static const CidConfig cid_fibocom_config [MBIM_CID_FIBOCOM_LAST] = {
+    { SET, NO_QUERY, NO_NOTIFY }, /* MBIM_CID_FIBOCOM_AT_COMMAND */
+};
+
+/* Note: index of the array is CID-1 */
+#define MBIM_CID_COMPAL_LAST MBIM_CID_COMPAL_AT_COMMAND
+static const CidConfig cid_compal_config [MBIM_CID_COMPAL_LAST] = {
+    { NO_SET, QUERY, NO_NOTIFY } /* MBIM_CID_COMPAL_AT_COMMAND */
+};
+
+/* Note: index of the array is CID-1 */
+#define MBIM_CID_INTEL_AT_TUNNEL_LAST MBIM_CID_INTEL_AT_TUNNEL_AT_COMMAND
+static const CidConfig cid_intel_at_tunnel_config [MBIM_CID_INTEL_AT_TUNNEL_LAST] = {
+    { SET, NO_QUERY, NO_NOTIFY } /* MBIM_CID_INTEL_AT_TUNNEL_AT_COMMAND */
+};
 gboolean
 mbim_cid_can_set (MbimService service,
                   guint       cid)
@@ -279,6 +325,18 @@ mbim_cid_can_set (MbimService service,
         return cid_intel_thermal_rf_config[cid - 1].set;
     case MBIM_SERVICE_MS_VOICE_EXTENSIONS:
         return cid_ms_voice_extensions_config[cid - 1].set;
+    case MBIM_SERVICE_INTEL_MUTUAL_AUTHENTICATION:
+        return cid_intel_mutual_authentication_config[cid - 1].set;
+    case MBIM_SERVICE_INTEL_TOOLS:
+        return cid_intel_tools_config[cid - 1].set;
+    case MBIM_SERVICE_GOOGLE:
+        return cid_google_config[cid - 1].set;
+    case MBIM_SERVICE_FIBOCOM:
+        return cid_fibocom_config[cid - 1].set;
+    case MBIM_SERVICE_COMPAL:
+        return cid_compal_config[cid - 1].set;
+    case MBIM_SERVICE_INTEL_AT_TUNNEL:
+        return cid_intel_at_tunnel_config[cid - 1].set;
     case MBIM_SERVICE_INVALID:
     case MBIM_SERVICE_LAST:
     default:
@@ -338,6 +396,18 @@ mbim_cid_can_query (MbimService service,
         return cid_intel_thermal_rf_config[cid - 1].query;
     case MBIM_SERVICE_MS_VOICE_EXTENSIONS:
         return cid_ms_voice_extensions_config[cid - 1].query;
+    case MBIM_SERVICE_INTEL_MUTUAL_AUTHENTICATION:
+        return cid_intel_mutual_authentication_config[cid - 1].query;
+    case MBIM_SERVICE_INTEL_TOOLS:
+        return cid_intel_tools_config[cid - 1].query;
+    case MBIM_SERVICE_GOOGLE:
+        return cid_google_config[cid - 1].query;
+    case MBIM_SERVICE_FIBOCOM:
+        return cid_fibocom_config[cid - 1].query;
+    case MBIM_SERVICE_COMPAL:
+        return cid_compal_config[cid - 1].query;
+    case MBIM_SERVICE_INTEL_AT_TUNNEL:
+        return cid_intel_at_tunnel_config[cid - 1].query;
     case MBIM_SERVICE_INVALID:
     case MBIM_SERVICE_LAST:
     default:
@@ -397,6 +467,18 @@ mbim_cid_can_notify (MbimService service,
         return cid_intel_thermal_rf_config[cid - 1].notify;
     case MBIM_SERVICE_MS_VOICE_EXTENSIONS:
         return cid_ms_voice_extensions_config[cid - 1].notify;
+    case MBIM_SERVICE_INTEL_MUTUAL_AUTHENTICATION:
+        return cid_intel_mutual_authentication_config[cid - 1].notify;
+    case MBIM_SERVICE_INTEL_TOOLS:
+        return cid_intel_tools_config[cid - 1].notify;
+    case MBIM_SERVICE_GOOGLE:
+        return cid_google_config[cid - 1].notify;
+    case MBIM_SERVICE_FIBOCOM:
+        return cid_fibocom_config[cid - 1].notify;
+    case MBIM_SERVICE_COMPAL:
+        return cid_compal_config[cid - 1].notify;
+    case MBIM_SERVICE_INTEL_AT_TUNNEL:
+        return cid_intel_at_tunnel_config[cid - 1].notify;
     case MBIM_SERVICE_INVALID:
     case MBIM_SERVICE_LAST:
     default:
@@ -457,6 +539,19 @@ mbim_cid_get_printable (MbimService service,
         return mbim_cid_intel_thermal_rf_get_string (cid);
     case MBIM_SERVICE_MS_VOICE_EXTENSIONS:
         return mbim_cid_ms_voice_extensions_get_string (cid);
+    case MBIM_SERVICE_INTEL_MUTUAL_AUTHENTICATION:
+        return mbim_cid_intel_mutual_authentication_get_string (cid);
+    case MBIM_SERVICE_INTEL_TOOLS:
+        return mbim_cid_intel_tools_get_string (cid);
+    case MBIM_SERVICE_GOOGLE:
+        return mbim_cid_google_get_string (cid);
+    case MBIM_SERVICE_FIBOCOM:
+        return mbim_cid_fibocom_get_string (cid);
+    case MBIM_SERVICE_COMPAL:
+        return mbim_cid_compal_get_string (cid);
+    case MBIM_SERVICE_INTEL_AT_TUNNEL:
+        return mbim_cid_intel_at_tunnel_get_string (cid);
+
     case MBIM_SERVICE_LAST:
     default:
         g_assert_not_reached ();
