@@ -4,6 +4,7 @@
  * libmbim-glib -- GLib/GIO based library to control MBIM devices
  *
  * Copyright (C) 2013 - 2018 Aleksander Morgado <aleksander@aleksander.es>
+ * Copyright (C) 2022 Intel Corporation
  */
 
 #ifndef _LIBMBIM_GLIB_MBIM_CID_H_
@@ -308,18 +309,20 @@ typedef enum { /*< since=1.16 >*/
  * @MBIM_CID_QDU_FILE_WRITE: Write QDU file for firmware update.
  * @MBIM_CID_QDU_QUECTEL_REBOOT: Reboot to Emergency Download (Quectel specific). Since 1.28.
  * @MBIM_CID_QDU_QUECTEL_READ_VERSION: Read firmware version (Quectel specific). Since 1.28.
+ * @MBIM_CID_QDU_COMMAND: Send AT or system command by mbim port. Since 1.32.
  *
  * MBIM commands in the %MBIM_SERVICE_QDU service.
  *
  * Since: 1.26
  */
 typedef enum { /*< since=1.26 >*/
-    MBIM_CID_QDU_UNKNOWN             = 0,
-    MBIM_CID_QDU_UPDATE_SESSION      = 1,
-    MBIM_CID_QDU_FILE_OPEN           = 2,
-    MBIM_CID_QDU_FILE_WRITE          = 3,
-    MBIM_CID_QDU_QUECTEL_REBOOT      = 4,
-    MBIM_CID_QDU_QUECTEL_READ_VERSION = 7
+    MBIM_CID_QDU_UNKNOWN              = 0,
+    MBIM_CID_QDU_UPDATE_SESSION       = 1,
+    MBIM_CID_QDU_FILE_OPEN            = 2,
+    MBIM_CID_QDU_FILE_WRITE           = 3,
+    MBIM_CID_QDU_QUECTEL_REBOOT       = 4,
+    MBIM_CID_QDU_QUECTEL_READ_VERSION = 7,
+    MBIM_CID_QDU_COMMAND              = 8
 } MbimCidQdu;
 
 /**
@@ -442,6 +445,90 @@ typedef enum { /*< since=1.28 >*/
     MBIM_CID_MS_VOICE_EXTENSIONS_NITZ    = 10,
 } MbimCidMsVoiceExtensions;
 
+/**
+ * MbimCidIntelMutualAuthentication:
+ * @MBIM_CID_INTEL_MUTUAL_AUTHENTICATION_UNKNOWN: Unknown command.
+ * @MBIM_CID_INTEL_MUTUAL_AUTHENTICATION_FCC_LOCK: FCC lock set.
+ *
+ * MBIM commands in the %MBIM_SERVICE_INTEL_MUTUAL_AUTHENTICATION service.
+ *
+ * Since: 1.30
+ */
+typedef enum { /*< since=1.30 >*/
+    MBIM_CID_INTEL_MUTUAL_AUTHENTICATION_UNKNOWN  = 0,
+    MBIM_CID_INTEL_MUTUAL_AUTHENTICATION_FCC_LOCK = 1,
+} MbimCidIntelMutualAuthentication;
+
+/**
+ * MbimCidIntelTools:
+ * @MBIM_CID_INTEL_TOOLS_UNKNOWN: Unknown command.
+ * @MBIM_CID_INTEL_TOOLS_TRACE_CONFIG: Configure Modem traces.
+ *
+ * MBIM commands in the %MBIM_SERVICE_INTEL_TOOLS service.
+ *
+ * Since: 1.30
+ */
+typedef enum { /*< since=1.30 >*/
+    MBIM_CID_INTEL_TOOLS_UNKNOWN      = 0,
+    MBIM_CID_INTEL_TOOLS_TRACE_CONFIG = 8,
+} MbimCidIntelTools;
+
+/**
+ * MbimCidGoogle:
+ * @MBIM_CID_GOOGLE_UNKNOWN: Unknown command.
+ * @MBIM_CID_GOOGLE_CARRIER_LOCK: Carrier lock.
+ *
+ * MBIM commands in the %MBIM_SERVICE_GOOGLE service.
+ *
+ * Since: 1.30
+ */
+typedef enum { /*< since=1.30 >*/
+    MBIM_CID_GOOGLE_UNKNOWN      = 0,
+    MBIM_CID_GOOGLE_CARRIER_LOCK = 1,
+} MbimCidGoogle;
+
+/**
+ * MbimCidFibocom:
+ * @MBIM_CID_FIBOCOM_UNKNOWN: Unknown command.
+ * @MBIM_CID_FIBOCOM_AT_COMMAND: AT over MBIM message.
+ *
+ * MBIM commands in the %MBIM_SERVICE_FIBOCOM service.
+ *
+ * Since: 1.32
+ */
+typedef enum { /*< since=1.32 >*/
+    MBIM_CID_FIBOCOM_UNKNOWN      = 0,
+    MBIM_CID_FIBOCOM_AT_COMMAND   = 1,
+} MbimCidFibocom;
+
+/**
+ * MbimCidCompal:
+ * @MBIM_CID_COMPAL_UNKNOWN: Unknown command.
+ * @MBIM_CID_COMPAL_AT_COMMAND: AT over MBIM message.
+ *
+ * MBIM commands in the %MBIM_SERVICE_COMPAL service.
+ *
+ * Since: 1.32
+ */
+typedef enum { /*< since=1.32 >*/
+    MBIM_CID_COMPAL_UNKNOWN    = 0,
+    MBIM_CID_COMPAL_AT_COMMAND = 1,
+} MbimCidCompal;
+
+/**
+ * MbimCidIntelAtTunnel:
+ * @MBIM_CID_INTEL_AT_TUNNEL_UNKNOWN: Unknown command.
+ * @MBIM_CID_INTEL_AT_TUNNEL_AT_COMMAND: AT over MBIM message.
+ *
+ * MBIM commands in the %MBIM_SERVICE_INTEL_AT_TUNNEL service.
+ *
+ * Since: 1.34
+ */
+typedef enum { /*< since=1.34 >*/
+    MBIM_CID_INTEL_AT_TUNNEL_UNKNOWN    = 0,
+    MBIM_CID_INTEL_AT_TUNNEL_AT_COMMAND = 1,
+} MbimCidIntelAtTunnel;
+
 /**
  * mbim_cid_can_set:
  * @service: a #MbimService.
