@@ -3,7 +3,8 @@
 /*
  * mbimcli -- Command line interface to control MBIM devices
  *
- * Copyright (C) 2013 - 2014 Aleksander Morgado <aleksander@aleksander.es>
+ * Copyright (C) 2013 - 2023 Aleksander Morgado <aleksander@aleksander.es>
+ * Copyright (C) 2022 Intel Corporation
  */
 
 #include "config.h"
@@ -45,6 +46,7 @@ static gboolean noop_flag;
 static gboolean verbose_flag;
 static gboolean verbose_full_flag;
 static gboolean silent_flag;
+static gchar *printable_str;
 static gboolean version_flag;
 
 static GOptionEntry main_entries[] = {
@@ -88,11 +90,15 @@ static GOptionEntry main_entries[] = {
       "Run action with no logs; not even the error/warning ones",
       NULL
     },
+    { "printable", 0, 0, G_OPTION_ARG_STRING, &printable_str,
+      "Get the printable info of the given hex encoded MBIM message",
+      "[(Data)]"
+    },
     { "version", 'V', 0, G_OPTION_ARG_NONE, &version_flag,
       "Print version",
       NULL
     },
-    { NULL }
+    { NULL, 0, 0, 0, NULL, NULL, NULL }
 };
 
 static gboolean
@@ -181,7 +187,7 @@ static void
 print_version_and_exit (void)
 {
     g_print (PROGRAM_NAME " " PROGRAM_VERSION "\n"
-             "Copyright (C) 2013-2021 Aleksander Morgado\n"
+             "Copyright (C) 2013-2023 Aleksander Morgado\n"
              "License GPLv2+: GNU GPL version 2 or later <http://gnu.org/licenses/gpl-2.0.html>\n"
              "This is free software: you are free to change and redistribute it.\n"
              "There is NO WARRANTY, to the extent permitted by law.\n"
@@ -189,6 +195,40 @@ print_version_and_exit (void)
     exit (EXIT_SUCCESS);
 }
 
+/*****************************************************************************/
+
+G_GNUC_NORETURN
+static void
+print_printable_str_and_exit (const gchar *hex)
+{
+    g_autofree gchar       *printable = NULL;
+    g_autoptr(MbimMessage)  message = NULL;
+    g_autoptr(GError)       error = NULL;
+    gsize                   data_size = 0;
+    g_autofree guint8      *data      = NULL;
+
+    data = mbimcli_read_buffer_from_string (hex, -1, &data_size, &error);
+    if (!data) {
+        g_printerr ("Failed to read data: %s\n", error->message);
+        exit (EXIT_FAILURE);
+    }
+
+    message = mbim_message_new (data, data_size);
+    if (!mbim_message_validate (message, &error)) {
+        g_printerr ("error: message validation failed: %s\n", error->message);
+        exit (EXIT_FAILURE);
+    }
+
+    printable = mbim_message_get_printable_full (message, 1, 0, "---- ", FALSE, &error);
+    if (!printable) {
+        g_printerr ("error: printable info retrieval failed: %s\n", error->message);
+        exit (EXIT_FAILURE);
+    }
+
+    g_print ("%s\n", printable);
+    exit (EXIT_SUCCESS);
+}
+
 /*****************************************************************************/
 /* Running asynchronously */
 
@@ -311,13 +351,34 @@ device_open_ready (MbimDevice   *dev,
     case MBIM_SERVICE_MS_UICC_LOW_LEVEL_ACCESS:
         mbimcli_ms_uicc_low_level_access_run (dev, cancellable);
         return;
+    case MBIM_SERVICE_INTEL_MUTUAL_AUTHENTICATION:
+        mbimcli_intel_mutual_authentication_run (dev, cancellable);
+        return;
+    case MBIM_SERVICE_GOOGLE:
+        mbimcli_google_run (dev, cancellable);
+        return;
     case MBIM_SERVICE_SMS:
+        mbimcli_sms_run (dev, cancellable);
+        return;
     case MBIM_SERVICE_USSD:
     case MBIM_SERVICE_STK:
     case MBIM_SERVICE_AUTH:
     case MBIM_SERVICE_PROXY_CONTROL:
     case MBIM_SERVICE_QMI:
     case MBIM_SERVICE_QDU:
+    case MBIM_SERVICE_INTEL_TOOLS:
+        mbimcli_intel_tools_run (dev, cancellable);
+        return;
+    case MBIM_SERVICE_FIBOCOM:
+        mbimcli_fibocom_run (dev, cancellable);
+        return;
+    case MBIM_SERVICE_COMPAL:
+        mbimcli_compal_run (dev, cancellable);
+        return;
+    case MBIM_SERVICE_INTEL_AT_TUNNEL:
+        mbimcli_intel_at_tunnel_run (dev, cancellable);
+        return;
+
         /* unsupported actions in the CLI */
     case MBIM_SERVICE_INVALID:
     default:
@@ -447,6 +508,41 @@ parse_actions (void)
         actions_enabled++;
     }
 
+    if (mbimcli_intel_mutual_authentication_options_enabled ()) {
+        service = MBIM_SERVICE_INTEL_MUTUAL_AUTHENTICATION;
+        actions_enabled++;
+    }
+
+    if (mbimcli_intel_tools_options_enabled ()) {
+        service = MBIM_SERVICE_INTEL_TOOLS;
+        actions_enabled++;
+    }
+
+    if (mbimcli_google_options_enabled ()) {
+        service = MBIM_SERVICE_GOOGLE;
+        actions_enabled++;
+    }
+
+    if (mbimcli_fibocom_options_enabled ()) {
+        service = MBIM_SERVICE_FIBOCOM;
+        actions_enabled++;
+    }
+
+    if (mbimcli_sms_options_enabled()) {
+        service = MBIM_SERVICE_SMS;
+        actions_enabled++;
+    }
+
+    if (mbimcli_compal_options_enabled ()) {
+        service = MBIM_SERVICE_COMPAL;
+        actions_enabled++;
+    }
+
+    if (mbimcli_intel_at_tunnel_options_enabled ()) {
+        service = MBIM_SERVICE_INTEL_AT_TUNNEL;
+        actions_enabled++;
+    }
+
     /* Noop */
     if (noop_flag)
         actions_enabled++;
@@ -495,6 +591,14 @@ int main (int argc, char **argv)
     g_option_context_add_group (context, mbimcli_intel_thermal_rf_get_option_group ());
     g_option_context_add_group (context, mbimcli_ms_voice_extensions_get_option_group ());
     g_option_context_add_group (context, mbimcli_ms_uicc_low_level_access_get_option_group ());
+    g_option_context_add_group (context, mbimcli_intel_mutual_authentication_get_option_group ());
+    g_option_context_add_group (context, mbimcli_intel_tools_get_option_group ());
+    g_option_context_add_group (context, mbimcli_google_get_option_group());
+    g_option_context_add_group (context, mbimcli_fibocom_get_option_group());
+    g_option_context_add_group (context, mbimcli_sms_get_option_group ());
+    g_option_context_add_group (context, mbimcli_compal_get_option_group ());
+    g_option_context_add_group (context, mbimcli_intel_at_tunnel_get_option_group ());
+
     g_option_context_add_main_entries (context, main_entries, NULL);
     if (!g_option_context_parse (context, &argc, &argv, &error)) {
         g_printerr ("error: %s\n", error->message);
@@ -518,6 +622,9 @@ int main (int argc, char **argv)
         mbim_utils_set_show_personal_info (TRUE);
     }
 
+    if (printable_str)
+        print_printable_str_and_exit (printable_str);
+
     /* No device path given? */
     if (!device_str) {
         g_printerr ("error: no device path specified\n");
