@@ -38,6 +38,7 @@ GOptionGroup *mbimcli_google_get_option_group                      (void);
 GOptionGroup *mbimcli_fibocom_get_option_group                     (void);
 GOptionGroup *mbimcli_sms_get_option_group                         (void);
 GOptionGroup *mbimcli_compal_get_option_group                      (void);
+GOptionGroup *mbimcli_intel_at_tunnel_get_option_group             (void);
 
 gboolean      mbimcli_basic_connect_options_enabled               (void);
 gboolean      mbimcli_phonebook_options_enabled                   (void);
@@ -58,6 +59,7 @@ gboolean      mbimcli_google_options_enabled                      (void);
 gboolean      mbimcli_fibocom_options_enabled                     (void);
 gboolean      mbimcli_sms_options_enabled                         (void);
 gboolean      mbimcli_compal_options_enabled                      (void);
+gboolean      mbimcli_intel_at_tunnel_options_enabled             (void);
 
 void          mbimcli_basic_connect_run                 (MbimDevice   *device,
                                                          GCancellable *cancellable);
@@ -97,6 +99,8 @@ void          mbimcli_sms_run                           (MbimDevice *device,
                                                          GCancellable *cancellable);
 void          mbimcli_compal_run                        (MbimDevice *device,
                                                          GCancellable *cancellable);
+void          mbimcli_intel_at_tunnel_run               (MbimDevice *device,
+                                                         GCancellable *cancellable);
 
 /* link management */
 GOptionGroup *mbimcli_link_management_get_option_group (void);
